# NOTE: pyscript
from pyscript import document, display, window, when

import tempfile
import os
import asyncio
# NOTE: libs
import GaussNBO as gnbo
from jinja2 import Environment, FileSystemLoader


async def parse_file(event):
    """
    Parse the file content using GaussNBO and display the result.
    """
    temp_file_path = None
    try:
        # Parse the file content using GaussNBO
        raw_data = document.getElementById('fileContent').textContent
        
        # Create a temporary file to store the content
        with tempfile.NamedTemporaryFile(delete=False, suffix='.log', mode='w+') as temp_file:
            temp_file.write(raw_data)
            temp_file_path = temp_file.name
        
        # spinner 
        spinner = document.getElementById('parsing-spinner')
        
        # show spinner
        spinner.style.display = 'block'
        
        # Use GaussNBO to parse the temporary file
        parsed_data = await asyncio.to_thread(gnbo.launch,
            file_path=temp_file_path,
            view_browser=False)
        
        # parsed_data = gnbo.launch(
        #     file_path=temp_file_path,
        #     view_browser=False)
        
        # hide spinner
        spinner.style.display = 'none'
        
        # Render the template with parsed data
        env = Environment(loader=FileSystemLoader('templates'))
        template = env.get_template('nbo.html')
        rendered_html = template.render(data=parsed_data)
        
        # Display the rendered HTML
        output_div = document.getElementById('output')
        output_div.innerHTML = rendered_html
    except Exception as e:
        display(f"Error parsing file: {e}", target="output")
    finally:
        # Clean up the temporary file if it was created
        if temp_file_path and os.path.exists(temp_file_path):
            os.unlink(temp_file_path)


def parse_test_file(event):
    """
    Parse the file content using GaussNBO and display the result.
    """
    print("Parsing test file...")
    try:
        # test
        parsed_data = {
            'title': 'NBO Analysis',
            'content': '123',
        }
        
        # Use the template directory defined globally
        env = Environment(loader=FileSystemLoader('templates'))
        template = env.get_template('parent.html')
        rendered_html = template.render(data=parsed_data)
        
        print(rendered_html)
        
        # Display the rendered HTML
        # display(rendered_html, target="output")
        output_div = document.getElementById('output')
        output_div.innerHTML = rendered_html
    except Exception as e:
        display(f"Error parsing file: {e}", target="output")
